# Contributing

## How to Contribute
- Fork the repo, make a branch, submit a pull request
- Follow existing code style
- Add/maintain docstrings and type hints
- Add tests for new features (see `tests/`)

## Running Tests

```bash
pytest tests/
```

## Feature Ideas
- More provider integrations
- Web UI
- Improved docs
- Implement "from_loom" in the ChatNode
- Implement more database and usage tracking for other providers

---

Thank you for making MiniLLMLib better!